Crate infmachine_gen

Crate infmachine_gen 

InfMachine Gen

This library provides utilities to generate Infinite Machines. The Infinite Machine model is described in documentation of infmachine crate. This library uses gategen library to generate and create circuits. This library uses intvar and dynintvar object to holds variables. Main structure of that library is InfParMachineObject that holds input and outputs of machine’s circuit. After filling all circuit outputs it possible to create machine description from that object.

Examples of usage that library in crate infmachine_examples.

More information in infmachine crate.

Re-exports

pub use gategen;
pub use gategen::gatesim;
pub use gategen::gateutil;
pub use infmachine_config;

Structs

InfParInput
Structure holds circuit input variables.
InfParMachineObject
Main structure describes circuit using gategen variables.
InfParOutput
Structure that describes machine circuit outputs.

Constants

DKIND_MEM_ADDRESS
Constant for data kind. For memory address.
DKIND_PROC_ID
Constant for data kind. For processor id.
DKIND_PROC_ID_2
Constant for data kind. For processor id.
DKIND_TEMP_BUFFER
Constant for data kind. For temp buffer.
DPMOVE_BACKWARD
Constant for data part move. For move backward.
DPMOVE_BACKWARD_2
Constant for data part move. For move backward.
DPMOVE_FORWARD
Constant for data part move. For move forward.
DPMOVE_NOTHING
Constant for data part move. For do nothing.

Type Aliases

InfParInput16
Circuit input type for circuit with 16-bit type.
InfParInput32
Circuit input type for circuit with 32-bit type.
InfParInputSys
Circuit input type for circuit with system type.
InfParMachineObject16
InfParMachineObject32
InfParMachineObjectSys
InfParOutput16
Circuit output type for circuit with 16-bit type.
InfParOutput32
Circuit output type for circuit with 32-bit type.
InfParOutputSys
Circuit output type for circuit with system type.