InfMachine Gen
This library provides utilities to generate Infinite Machines.
The Infinite Machine model is described in documentation of infmachine crate.
This library uses gategen library to generate and create circuits.
This library uses intvar and dynintvar object to holds variables.
Main structure of that library is InfParMachineObject that holds
input and outputs of machine’s circuit.
After filling all circuit outputs it possible to create machine description
from that object.
Examples of usage that library in crate infmachine_examples.
More information in infmachine crate.
Re-exports
pub use gategen;pub use gategen::gatesim;pub use gategen::gateutil;pub use infmachine_config;
Structs
- InfPar
Input - Structure holds circuit input variables.
- InfPar
Machine Object - Main structure describes circuit using
gategenvariables. - InfPar
Output - Structure that describes machine circuit outputs.
Constants
- DKIND_
MEM_ ADDRESS - Constant for data kind. For memory address.
- DKIND_
PROC_ ID - Constant for data kind. For processor id.
- DKIND_
PROC_ ID_ 2 - Constant for data kind. For processor id.
- DKIND_
TEMP_ BUFFER - Constant for data kind. For temp buffer.
- DPMOVE_
BACKWARD - Constant for data part move. For move backward.
- DPMOVE_
BACKWARD_ 2 - Constant for data part move. For move backward.
- DPMOVE_
FORWARD - Constant for data part move. For move forward.
- DPMOVE_
NOTHING - Constant for data part move. For do nothing.
Type Aliases
- InfPar
Input16 - Circuit input type for circuit with 16-bit type.
- InfPar
Input32 - Circuit input type for circuit with 32-bit type.
- InfPar
Input Sys - Circuit input type for circuit with system type.
- InfPar
Machine Object16 - InfPar
Machine Object32 - InfPar
Machine Object Sys - InfPar
Output16 - Circuit output type for circuit with 16-bit type.
- InfPar
Output32 - Circuit output type for circuit with 32-bit type.
- InfPar
Output Sys - Circuit output type for circuit with system type.