pub struct InfParOutput<T: VarLit> {
pub state: DynIntVar<T, false>,
pub memval: DynIntVar<T, false>,
pub dpval: DynIntVar<T, false>,
pub memr: BoolVar<T>,
pub memw: BoolVar<T>,
pub dpr: BoolVar<T>,
pub dpw: BoolVar<T>,
pub dpmove: IntVar<T, U2, false>,
pub dkind: IntVar<T, U2, false>,
pub stop: BoolVar<T>,
}Expand description
Structure that describes machine circuit outputs.
Fields
state: DynIntVar<T, false>Output internal state.
memval: DynIntVar<T, false>Output main memory cell value to write to memory.
dpval: DynIntVar<T, false>Output data part to write into internal data (memory address or temp buffer).
memr: BoolVar<T>Output memory read bit. If true then machine reads memory.
memw: BoolVar<T>Output memory write bit. If true then machine writes into memory.
dpr: BoolVar<T>Output data part read bit. If true then machine reads internal data.
dpw: BoolVar<T>Output data part write bit. If true then machine writes internal data.
dpmove: IntVar<T, U2, false>Output data part move. Set move of position for internal data.
dkind: IntVar<T, U2, false>Output data kind. Specifies internal data kind that operates machine.
stop: BoolVar<T>Output stop machine indicator. If true then machine stops.
Implementations
Sourceimpl InfParOutput<i16>
impl InfParOutput<i16>
Sourcepub fn new(config: InfParInterfaceConfig) -> Self
pub fn new(config: InfParInterfaceConfig) -> Self
Creates circuit output object from interface configuration. All outputs are filled by default values.
Sourcepub fn fix_state_len(list: &mut [Self])
pub fn fix_state_len(list: &mut [Self])
Fix internal state length from list of other circuit output objects.
Sourcepub fn new_from_dynintvar(
config: InfParInterfaceConfig,
var: DynIntVar<i16, false>,
) -> Self
pub fn new_from_dynintvar( config: InfParInterfaceConfig, var: DynIntVar<i16, false>, ) -> Self
Creates new from dynintvar. config is interface configuration.
var is variable of all outputs.
Sourceimpl InfParOutput<i32>
impl InfParOutput<i32>
Sourcepub fn new(config: InfParInterfaceConfig) -> Self
pub fn new(config: InfParInterfaceConfig) -> Self
Creates circuit output object from interface configuration. All outputs are filled by default values.
Sourcepub fn fix_state_len(list: &mut [Self])
pub fn fix_state_len(list: &mut [Self])
Fix internal state length from list of other circuit output objects.
Sourcepub fn new_from_dynintvar(
config: InfParInterfaceConfig,
var: DynIntVar<i32, false>,
) -> Self
pub fn new_from_dynintvar( config: InfParInterfaceConfig, var: DynIntVar<i32, false>, ) -> Self
Creates new from dynintvar. config is interface configuration.
var is variable of all outputs.
Sourceimpl InfParOutput<isize>
impl InfParOutput<isize>
Sourcepub fn new(config: InfParInterfaceConfig) -> Self
pub fn new(config: InfParInterfaceConfig) -> Self
Creates circuit output object from interface configuration. All outputs are filled by default values.
Sourcepub fn fix_state_len(list: &mut [Self])
pub fn fix_state_len(list: &mut [Self])
Fix internal state length from list of other circuit output objects.
Sourcepub fn new_from_dynintvar(
config: InfParInterfaceConfig,
var: DynIntVar<isize, false>,
) -> Self
pub fn new_from_dynintvar( config: InfParInterfaceConfig, var: DynIntVar<isize, false>, ) -> Self
Creates new from dynintvar. config is interface configuration.
var is variable of all outputs.